NAAM
====

*No Argparse Any More.*

Don’t google argparse just take some NAAM
-----------------------------------------

-  I forget how to use argparse every time I make utilities
-  10+ lines for just parsing arguments? No way!
-  There should be a super pythonic way to parse arguments!!!!
-  `I love Kizuna Ai. <https://www.youtube.com/watch?v=COXCojRKbk8>`__

Prerequisites
-------------

No dependencies. Works on Python 3.x (Built on Python 3.6.2).

Features I crave
----------------

-  Type casting for type-annotated args

